@@ -1,6 +1,14 @@
 from __future__ import unicode_literals
 
+try:
+    # Python 3
+    from urllib.parse import urlencode
+except ImportError:
+    # Python 2
+    from urllib import urlencode
+
 from django.contrib.sites.models import Site
+from django.contrib.staticfiles.templatetags.staticfiles import static
 from django.core.urlresolvers import reverse
 from django.utils.html import strip_tags
 from django.utils.unittest import skipUnless
@@ -220,3 +228,10 @@ class CoreTests(TestCase):
 
         site1.delete()
         site2.delete()
+
+    def test_static_proxy(self):
+        self.client.login(username=self._username, password=self._password)
+        querystring = urlencode([('u', static("test/image.jpg"))])
+        proxy_url = '%s?%s' % (reverse('static_proxy'), querystring)
+        response = self.client.get(proxy_url)
+        self.assertEqual(response.status_code, 200)
