@@ -47,7 +47,7 @@ def ip_for_request(request):
     header, since app will generally be behind a public web server.
     """
     meta = request.META
-    return meta.get("HTTP_X_FORWARDED_FOR", meta["REMOTE_ADDR"])
+    return meta.get("HTTP_X_FORWARDED_FOR", meta["REMOTE_ADDR"]).split(",")[0]
 
 
 def is_spam_akismet(request, form, url):
